@@ -6,7 +6,7 @@ use components_arena::{Component, ComponentId, Id, Arena, RawId, ComponentClassT
 use components_arena::{ComponentClassMutex};
 use core::fmt::Debug;
 use downcast_rs::{Downcast, impl_downcast};
-use dyn_context::{State, StateExt};
+use dyn_context::{SelfState, State, StateExt};
 use educe::Educe;
 use macro_attr_2018::macro_attr;
 #[cfg(feature="std")]
@@ -138,10 +138,10 @@ macro_attr! {
     pub struct Flow<T: Convenient>(Id<FlowBox>, PhantomType<T>);
 }
 
-macro_attr! {
-    #[derive(Debug, State!)]
-    pub struct Flows(Arena<FlowBox>);
-}
+#[derive(Debug)]
+pub struct Flows(Arena<FlowBox>);
+
+impl SelfState for Flows { }
 
 impl Flows {
     pub fn new(token: &mut FlowsToken) -> Self { Flows(Arena::new(&mut token.0)) }
