@@ -9,6 +9,9 @@
 #![feature(unchecked_math)]
 
 #![deny(warnings)]
+#![doc(test(attr(deny(warnings))))]
+#![doc(test(attr(allow(dead_code))))]
+#![doc(test(attr(allow(unused_variables))))]
 
 #![cfg_attr(not(feature="std"), no_std)]
 #[cfg(feature="std")]
@@ -68,7 +71,7 @@ pub mod example {
 
     use crate::{dep_obj, dep_type};
     use components_arena::{Arena, Component, NewtypeComponentId, Id};
-    use dyn_context::State;
+    use dyn_context::SelfState;
 
     dep_type! {
         #[derive(Debug)]
@@ -95,7 +98,7 @@ pub mod example {
         my_dep_types: Arena<MyDepTypePrivateData>,
     }
 
-    State!(() pub struct MyApp { .. });
+    impl SelfState for MyApp { }
 
     impl MyDepTypeId {
         pub fn new(app: &mut MyApp) -> MyDepTypeId {
@@ -1130,7 +1133,7 @@ macro_rules! dep_type_impl_raw {
                     $vis fn $field(mut self, value: $field_ty) -> Self {
                         let id = <$BuilderCore as $crate::DepObjBuilderCore<$Id>>::id(&self.core);
                         let state = <$BuilderCore as $crate::DepObjBuilderCore<$Id>>::state_mut(&mut self.core);
-                        id. $obj (state).set_uncond($name:: [< $field:upper >] , value);
+                        id. $obj (state).prop($name:: [< $field:upper >] ).set_uncond(value);
                         self
                     }
                 ]
